scoretools.move_measure_prolation_to_full_measure_tuplet
========================================================

.. autofunction:: abjad.tools.scoretools.move_measure_prolation_to_full_measure_tuplet.move_measure_prolation_to_full_measure_tuplet
